pub enum TrifleError {
Show 24 variants
NumericalOverflow,
InvalidAccount,
InvalidEscrowConstraintModel,
InvalidEscrowConstraint,
EscrowConstraintViolation,
InvalidUpdateAuthority,
FailedToCreatePubkey,
DataTypeMismatch,
ConstraintAlreadyExists,
TokenLimitExceeded,
FailedToFindTokenAmount,
InvalidCollectionMetadata,
TransferEffectConflict,
FreezeAuthorityNotSet,
CannotBurnPrintEdition,
ConstraintKeyNotFound,
FailedToSerialize,
FailedToBorrowAccountData,
InvalidCollection,
MustBeHolder,
InvalidFirstCreator,
IncorrectOwner,
DerivedKeyInvalid,
KeyMismatch,
}Variants
NumericalOverflow
0 - Numerical Overflow
InvalidAccount
1 - Invalid account
InvalidEscrowConstraintModel
2 - Invalid Escrow Constraint Model
InvalidEscrowConstraint
3 - Invalid Escrow Constraint
EscrowConstraintViolation
4 - Escrow Constraint Violation
InvalidUpdateAuthority
5 - Invalid Update Authority
FailedToCreatePubkey
6 - Failed to create pubkey
DataTypeMismatch
7 - Data type mismatch
ConstraintAlreadyExists
8 - Constraint already exists
TokenLimitExceeded
9 - Token limit exceeded
FailedToFindTokenAmount
10 - Failed to find the token amount
InvalidCollectionMetadata
11 - The collection metadata is invalid
TransferEffectConflict
12 - This set of Transfer Effects can not be used together
FreezeAuthorityNotSet
13 - The freeze authority is not set
CannotBurnPrintEdition
14 - Cannot burn Print Edition
ConstraintKeyNotFound
15 - The constraint key was not found
FailedToSerialize
16 - The data failed to serialize
FailedToBorrowAccountData
17 - Account data borrow failed
InvalidCollection
18 - Failed to deserialize the collection
MustBeHolder
19 - Only the holder is allowed to perform this action
InvalidFirstCreator
20 - Failed to deserialize the first creator
IncorrectOwner
21 - Incorrect account owner
DerivedKeyInvalid
22 Derived key invalid
KeyMismatch
23 - Public key does not match expected value